<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


//---------- ./homesite/includes/login.php ----------

// Global section Box Login (GBL) when user is not loged in

$GBL001="Login";
$GBL002="Nombre:";
$GBL003="Contrase&ntilde;a:";
$GBL004="Crear un usuario";
$GBL005="Entrar"; //Text value for submit button

// GBL when user is loging in

$GBL006="Bienvenido";
$GBL007="Autenticaci&oacute;n Correcta.<br>".
        "Acabas de conectar como un usuairo registrado<br><br>".
        "Si continuas, podr&aacute;s acceder a las funciones de usuario.<br>".
        "Se cuidadoso !";
$GBL008="Continuar";

// GBL when user is already logged

$GBL009="Estas logeado como";
$GBL010="Funciones de Usuario:";
$GBL011="Panel de Control";
$GBL012="Noticias Pendientes";
$GBL013="Albumes Pendientes";
$GBL014="Items Pendientes";
$GBL015="Ayuda";
$GBL016="Desconectar";
$GBL017="NOMBRE INCORRECTO!";
$GBL018="CONTRASE&ntilde;A INCORRECTA!";

?>
